@@ -1,11 +1,11 @@
-from . import word
-from . import pdf
-from . import image
-from . import file
-from . import video
-from . import tools
-from . import ppt
-from . import excel
+from office.api import word
+from office.api import pdf
+from office.api import image
+from office.api import file
+from office.api import video
+from office.api import tools
+from office.api import ppt
+from office.api import excel
 
 print('=' * 30)
 print('【python-office库】，功能持续更新中')
